#pragma once
#include "pch.h"
#include "AbsFSController.h"

class MakeDCT :public QObject
{
	Q_OBJECT;
public:
	MakeDCT(QObject* parent = nullptr);
	virtual ~MakeDCT();
public:
	void SetRunParams(OneFSContext struFSRunParams);
	int  Initialize();
	int  Initialize_Part();
	int  MakeTable();
	int  LoadTable();
	void GetDCTable(std::vector<DataFrame> &vecDataFrame);
private:
	void Delay_MSec(ZZ_U16 usMS);

private:
	QString m_qstrDarkCurrentTable = "/home/data/Data/DCTable.txt";
	OneFSContext         m_struFSRunParams;
	CAbsFSController* m_pctrlFS;
	DeviceAttribute m_struDeviceAttr;
	std::vector<DataFrame> m_vecDataFrame;
};
